@@ -23,7 +23,7 @@ $tts=array();
 $tts['google']= array(
       "name" => "google",
       "call"  => "ttsgoogle",
-      "options" => array('"http://translate.google.com/translate_tts"','$text', '$lang','$filename'),
+      "options" => array('"http://translate.google.com/translate_tts"','$text', '$lang','$filename','$iformat'),
       "voices"=>array(
                       '1'  => array(
                           'type'=>'male',
@@ -42,21 +42,24 @@ $tts['google']= array(
                           ),
       "charsets" => array('UTF-8'),
       #internal codecs and formats  
-      "codecs" => array('pcm'=>'pcm'),
-      "iformats" => array('raw'),
+      "codecs" => array('alaw'=>'alaw','pcm'=>'pcm'),
+      "iformats" => array('raw','wav'),
       #which internal codecs and formats must be used to get good VXI formats
-      "vxiformats" => array('raw' => array('iformat'=>'raw','codec'=>'pcm')),
+      "vxiformats" => array('raw' => array('iformat'=>'raw','codec'=>'alaw'),
+                            'wav' => array('iformat'=>'wav','codec'=>'pcm'),
+      ),
       "formatiscodec"=>false,
       "createlistfile"=>false,
       "directphpfunction"=>true,
       "debugargs"=>"",
       "checks"=>array("ttsgoogle","curl_setopt","/usr/local/bin/ffmpeg"),
+      "simexeclimit"=>"0",
     );
 
 $tts['url']= array(
       "name" => "url",
       "call"  => "ttsurl",
-      "options" => array('"http://dev.realize.gr/innottsreader/default.aspx"','$text', '$voiceid','$rate','$pitch'),
+      "options" => array('"http://sample.com"','$text', '$voiceid','$rate','$pitch'),
       "voices"=>array(
                       'voice2'  => array(
                           'type'=>'male',
@@ -83,6 +86,7 @@ $tts['url']= array(
       "directphpfunction"=>true,
       "debugargs"=>"",
       "checks"=>array("ttsurl","curl_setopt","/usr/local/bin/ffmpeg"),
+      "simexeclimit"=>"0",
     );
 
 #curl_end
